@@ -122,9 +122,10 @@ my $startTime = gettime();
 ## Modified 23. Sep 2020 v2.2.3 (Vinh)	- use full taxonomy name instead of abbr taxon name for LOG
 ## Modified 01. Dec 2020 v2.2.4 (Vinh)	- fixed bug while creating final extended.fa (and replaced grep and sed by bioperl)
 ## Modified 16. Feb 2021 v2.2.5 (Vinh)	- core compilation works with fasoff
+## Modified 18. Feb 2021 v2.2.6 (Vinh)	- fixed searchTaxa and coreTaxa options
 
 ############ General settings
-my $version = 'oneSeq v.2.2.5';
+my $version = 'oneSeq v.2.2.6';
 ##### configure for checking if the setup.sh script already run
 my $configure = 0;
 if ($configure == 0){
@@ -134,10 +135,10 @@ if ($configure == 0){
 my $hostname = `hostname`;
 chomp $hostname;
 #############
-my $termios = new POSIX::Termios; $termios->getattr;
-my $ospeed = $termios->getospeed;
-my $t = Tgetent Term::Cap { TERM => undef, OSPEED => $ospeed };
-my ($norm, $under, $bold) = map { $t->Tputs($_,1) } qw/me md us/;
+# my $termios = new POSIX::Termios; $termios->getattr;
+# my $ospeed = $termios->getospeed;
+# my $t = Tgetent Term::Cap { TERM => undef, OSPEED => $ospeed };
+# my ($norm, $under, $bold) = map { $t->Tputs($_,1) } qw/me md us/;
 #### Paths
 my $path = abs_path(dirname(__FILE__));
 $path =~ s/\/bin//;
@@ -167,7 +168,7 @@ my $algorithm = "blastp";
 my $blast_prog = 'blastp';
 my $outputfmt = 'blastxml';
 my $eval_blast_query = 0.0001;
-my $filter = 'T';
+my $filter = 'F'; # default for blastp
 my $annotation_prog = "annoFAS";
 my $fas_prog = "calcFAS";
 my $fdogFAS_prog = "fdogFAS";
@@ -567,7 +568,7 @@ if (!$coreex) {
 
 		my $addedTaxon = getBestOrtholog();
 		my $addedTaxonName = getTaxonName($addedTaxon);
-		print "Added TAXON: $addedTaxon\_$addedTaxonName\n";
+		print "Added TAXON: $addedTaxon\t$addedTaxonName\n";
 		#if a new core ortholog was found
 		if($addedTaxon ne "") {
 			$hamstrSpecies = $hamstrSpecies . "," . $addedTaxon;
@@ -611,10 +612,10 @@ if (!$coreOnly) {
 
 	$taxaPath = $genome_dir;
 	my @searchTaxa;
-	unless($groupNode) {
-		@searchTaxa = keys %taxa;
-	} else {
-		unless ($searchTaxa) {
+	unless ($searchTaxa) {
+		unless($groupNode) {
+			@searchTaxa = keys %taxa;
+		} else {
 			# %taxa = getTaxa();
 			# print "GET TAXA TIME: ", roundtime(gettime() - $startTmp),"\n";
 			my $tree = getTree();
@@ -630,11 +631,11 @@ if (!$coreOnly) {
 			foreach (get_leaves($tree)) {
 				push(@searchTaxa, @{$_->name('supplied')}[0]);
 			}
-		} else {
-			open(SEARCH, $searchTaxa) || die "Cannot open $searchTaxa file!\n";
-			@searchTaxa = <SEARCH>;
-			close (SEARCH);
 		}
+	} else {
+		open(SEARCH, $searchTaxa) || die "Cannot open $searchTaxa file!\n";
+		@searchTaxa = <SEARCH>;
+		close (SEARCH);
 	}
 	# print "PREPARE TIME: ", roundtime(gettime() - $startTmp),"\n";
 
@@ -646,12 +647,23 @@ if (!$coreOnly) {
 	foreach (sort @searchTaxa) {
 		chomp(my $searchTaxon = $_);
 		my $pid = $pm->start and next;
+		if ($coreex) {
+			$db = Bio::DB::Taxonomy->new(-source    => 'flatfile',
+				-nodesfile => $idx_dir . 'nodes.dmp',
+				-namesfile => $idx_dir . 'names.dmp',
+				-directory => $idx_dir);
+			$db_bkp = $db;
+		}
 		my $searchTaxonName = getTaxonName($searchTaxon);
 		if (defined($searchTaxonName)) {
 			unless ($silent) {
 				print $searchTaxon, "\t", $searchTaxonName, "\n";
 			} else {
-				print $searchTaxonName, "\n";
+				unless ($searchTaxonName eq "Unk") {
+					print $searchTaxonName, "\n";
+				} else {
+					print $searchTaxon, "\n";
+				}
 			}
 		}
 		runHamstr($searchTaxon, $seqName, $finalOutput, $refSpec, $hitlimit, $representative, $strict, $coremode, $final_eval_blast, $final_eval_hmmer, $aln);
@@ -1244,13 +1256,13 @@ sub checkOptions {
 			print "Please specify a valid file with taxa for the core orthologs search\n";
 			exit;
 		}
-		my @userTaxa = parseTaxaFile();
+		my @userTaxa = parseTaxaFile($coreTaxa);
 		my %newTaxa = ();
 		foreach (@userTaxa) {
 			$newTaxa{$_} = $taxa{$_};
 		}
 		$newTaxa{$refSpec} = $refTaxa{$refSpec};
-		%taxa = %newTaxa;
+		%refTaxa = %newTaxa;
 	}
 
 	if($group) {
@@ -1911,7 +1923,7 @@ sub getTaxonName {
 	if (defined($taxon)) {
 		return($taxon->scientific_name);
 	} else {
-		return("Unk NCBI taxon for $taxAbbr");
+		return("Unk");
 	}
 }
 
@@ -2103,17 +2115,19 @@ sub parseInput {
 }
 ##########################
 sub parseTaxaFile {
-	open (INPUT, "<$coreTaxa") or die print "Error opening file with taxa for core orthologs search\n";
+	my $coreTaxaFile = $_[0];
+	open (INPUT, "<$coreTaxaFile") or die print "Error opening file with taxa for core orthologs search\n";
 	my @userTaxa;
 	while(<INPUT>) {
 		my $line = $_;
 		chomp($line);
-		if(!$taxa{$line}) {
-			print "You specified " . $line . " in your core orthologs file but the taxon is not in the database!\n";
-			exit;
-		}
-		else {
-			push(@userTaxa, $line);
+		if (length($line) > 0) {
+			if(!$taxa{$line}) {
+				print "You specified " . $line . " in your core orthologs file but the taxon is not in the database!\n";
+				exit;
+			} else {
+				push(@userTaxa, $line);
+			}
 		}
 	}
 	close INPUT;
@@ -2648,23 +2662,23 @@ sub roundtime { sprintf("%.2f", $_[0]); }
 ###########################
 sub helpMessage {
 	my $helpmessage = "
-${bold}YOU ARE RUNNING $version on $hostname$norm
+YOU ARE RUNNING $version on $hostname
 
 This program is freely distributed under a GPL.
 Copyright (c) GRL limited: portions of the code are from separate copyrights
 
-\n${bold}USAGE:${norm} oneSeq.pl -seqFile=<> -seqId=<>  -seqName=<> -refSpec=<> -minDist=<> -maxDist=<> [OPTIONS]
+\nUSAGE: oneSeq.pl -seqFile=<> -seqId=<>  -seqName=<> -refSpec=<> -minDist=<> -maxDist=<> [OPTIONS]
 
-${bold}OPTIONS:$norm
+OPTIONS:
 
-${bold}GENERAL$norm
+GENERAL
 
 -h
 	Invoke this help method
 -version
 	Print the program version
 
-${bold}REQUIRED$norm
+REQUIRED
 
 -seqFile=<>
 	Specifies the file containing the seed sequence (protein only) in fasta format.
@@ -2684,7 +2698,7 @@ ${bold}REQUIRED$norm
 -coreOrth=<>
 	Specify the number of orthologs added to the core set.
 
-${bold}USING NON-DEFAULT PATHS$norm
+USING NON-DEFAULT PATHS
 
 -outpath=<>
 	Specifies the path for the output directory. Default is $outputPath;
@@ -2697,7 +2711,7 @@ ${bold}USING NON-DEFAULT PATHS$norm
 -weightpath=<>
 	Specifies the path for the pre-calculated feature annotion directory. Default is $weightPath;
 
-${bold}ADDITIONAL OPTIONS$norm
+ADDITIONAL OPTIONS
 
 -append
 	Set this flag to append the output to existing output files
@@ -2784,7 +2798,7 @@ ${bold}ADDITIONAL OPTIONS$norm
 	Set the alignment strategy during core ortholog compilation to glocal.
 -searchTaxa
 	Input file containing list of search taxa.
-${bold}SPECIFYING FAS SUPPORT OPTIONS$norm
+SPECIFYING FAS SUPPORT OPTIONS
 
 -fasoff
 	Turn OFF FAS support. Default is ON.
@@ -2797,7 +2811,7 @@ ${bold}SPECIFYING FAS SUPPORT OPTIONS$norm
 -countercheck
 	Set this flag to counter-check your final profile. The FAS score will be computed in two ways (seed vs. hit and hit vs. seed).
 
-${bold}SPECIFYING EXTENT OF OUTPUT TO SCREEN$norm
+SPECIFYING EXTENT OF OUTPUT TO SCREEN
 
 -debug
 	Set this flag to obtain more detailed information about the programs actions
